@@ -1,15 +1,14 @@
-from typing import Dict, List
+from typing import List, Optional
 
 import numpy as np
 import pandas as pd
-from sklearn.preprocessing import LabelEncoder
 
 from exodusutils import internal
 
 
 def to_numeric_features_df(df: pd.DataFrame, target: str) -> pd.DataFrame:
     """
-    Extracts the numeric features from the dataframe, and return them as a new dataframe.
+    Extracts the numeric features from the dataframe, and returns them as a new dataframe.
 
     The numeric features include:
         - Columns declared with `data_type == DataType.double` in `feature_types`
@@ -32,54 +31,23 @@ def to_numeric_features_df(df: pd.DataFrame, target: str) -> pd.DataFrame:
     return pd.DataFrame(df[internal.get_numeric_features(df, target)])
 
 
-def apply_label_encoders(
-    df: pd.DataFrame, encoders: Dict[str, LabelEncoder]
-) -> pd.DataFrame:
-    """
-    Apply label encoders to `df`. If your model makes use of `label_encoding` method during training,
-    then during prediction this should be performed on the prediction dataframe.
-    """
-    df = df.copy()
-    for col, encoder in encoders.items():
-        df.loc[
-            ~df[col].isin(encoder.classes_), [col]
-        ] = np.nan  # unseen values in training data
-        df.loc[df[col].notnull(), [col]] = encoder.transform(
-            df.loc[df[col].notnull()][col]
-        )
-        df[col] = pd.to_numeric(pd.Series(df[col]), errors="coerce")
-    return df
-
-
-def apply_one_hot_encoding(
-    df: pd.DataFrame, categorical_columns_in_training: List[str]
-) -> pd.DataFrame:
-    """
-    Apply one-hot encoding to `df`. If your model makes use of `one_hot_encoding` method during training,
-    then during prediction this should be performed on the prediction dataframe.
-    """
-    categorical_columns_in_testing = internal.get_columns(df, object)
-    dummy = pd.get_dummies(df, columns=categorical_columns_in_testing, dtype=np.int64)
-    for c in categorical_columns_in_training:
-        if c not in categorical_columns_in_testing:
-            dummy[c] = 0
-    return dummy
-
 def remove_invalid_values(df: pd.DataFrame) -> pd.DataFrame:
     """
-    Removes the invalid values from the dataframe.
+    Removes the invalid values from the dataframe, and resets the index.
 
     The invalid values are:
     - `float("nan")` or `np.nan` in numeric columns
     - `""` in other types of columns
     """
-    return pd.DataFrame(df.replace("", np.nan).dropna())
+    return pd.DataFrame(df.replace("", np.nan).dropna()).reset_index(drop=True)
+
 
 def remove_datetime_columns(df: pd.DataFrame) -> pd.DataFrame:
     """
-    Removes all columns of dtype `datetime64`
+    Removes all columns of dtype `datetime64`.
     """
-    return df.drop(internal.get_columns(df, np.datetime64), axis=1)
+    return pd.DataFrame(df.drop(internal.get_columns(df, np.datetime64), axis=1))
+
 
 def fill_nan_with_mode(df: pd.DataFrame, columns: List[str]) -> pd.DataFrame:
     """
@@ -102,3 +70,27 @@ def fill_nan_with_mode(df: pd.DataFrame, columns: List[str]) -> pd.DataFrame:
     value = {col: internal.get_column_mode(df[col]) for col in columns}
     return df.fillna(value=value)
 
+
+def drop_blank(df: pd.DataFrame, target_column_name: Optional[str]) -> pd.DataFrame:
+    """
+    Drops the blank rows from the dataframe. If target column name is given, then all rows with `np.nan` or `\"\"` \
+in the target column will be discarded. Otherwise only rows with all `np.nan` or `\"\"` will be discarded.
+
+    Parameters
+    ----------
+    df : DataFrame
+        The dataframe to manipulate on.
+    target_column_name : Optional[str]
+        The target column name. Optional.
+
+    Returns
+    -------
+    DataFrame
+        The dataframe without blank rows.
+    """
+    if target_column_name is not None:
+        df[target_column_name] = df[target_column_name].replace("", np.nan)
+        dropped = df.dropna(subset=[target_column_name])
+    else:
+        dropped = pd.DataFrame(df.replace("", np.nan).dropna(how="all"))
+    return dropped.reset_index(drop=True)
