@@ -1,5 +1,5 @@
-from io import BytesIO
 import math
+from io import BytesIO
 from typing import List, Optional, Tuple
 
 import numpy as np
@@ -7,8 +7,8 @@ import pandas as pd
 
 from exodusutils.constants import DATETIME_COMPONENTS_PREFIX
 from exodusutils.enums import DataType, TimeUnit
-from exodusutils.schemas import Column
 from exodusutils.exceptions import ExodusBadRequest
+from exodusutils.schemas import Column
 
 
 def cast_columns(
@@ -51,7 +51,7 @@ def get_df(data: bytes, feature_types: List[Column]) -> pd.DataFrame:
     ).pipe(cast_df_types, feature_types)
 
 
-def prefix_datetime_cols_with_time_components(col: str) -> List[str]:
+def postfix_datetime_cols_with_time_components(col: str) -> List[str]:
     """
     Returns a list of str, representing the new time component names
 
@@ -65,7 +65,7 @@ def prefix_datetime_cols_with_time_components(col: str) -> List[str]:
     List[str]
         A list of new column names
     """
-    return [f"{t}_{col}" for t in DATETIME_COMPONENTS_PREFIX]
+    return [f"{col}_{t}" for t in DATETIME_COMPONENTS_PREFIX]
 
 
 def get_time_components(
@@ -90,7 +90,7 @@ A time component is a series of `np.int64`.
     """
     # Time components
     dt = df[col].dt
-    components = list(dt.year)
+    components = [dt.year]
 
     # quarter, month and week component
     if time_unit not in {TimeUnit.year}:
@@ -100,15 +100,15 @@ A time component is a series of `np.int64`.
 
     # weekday and date component
     if time_unit not in {TimeUnit.year, TimeUnit.month}:
-        components += [dt.weekday, dt.day]
+        components += [dt.weekday]
     else:
-        components += [None, None]
+        components += [None]
 
     # hour component
     if time_unit not in {TimeUnit.year, TimeUnit.month, TimeUnit.day}:
-        components.append(dt.hour)
+        components += [dt.hour.replace(0, 24), dt.minute, dt.second]
     else:
-        components.append(None)
+        components += [None, None, None]
 
     return components
 
@@ -177,6 +177,7 @@ def sanitize_pred_and_actual(
 
     return pred, actual
 
+
 def validate_columns(header: List[str], features: List[Column]) -> None:
     """
     Check if there are any required features in `features` that are missing from the dataframe
@@ -198,8 +199,11 @@ def validate_columns(header: List[str], features: List[Column]) -> None:
             the client is notified that the information supplied is invalid
     """
     for f in features:
-        if f.name not in header: # This means that a required field is missing from the dataframe
-            raise ExodusBadRequest(f"column {f.name} is missing from the prediction data")
+        if (
+            f.name not in header
+        ):  # This means that a required field is missing from the dataframe
+            raise ExodusBadRequest(f"column {f.name} is missing from the data")
+
 
 def get_column_mode(col) -> float:
     """
@@ -208,7 +212,64 @@ def get_column_mode(col) -> float:
     This is used to create labels for the previously unseen values in a label encoded categorical column.
     """
     mode = col.mode().values
-    if mode:
-        return 0.0 if math.isnan(mode[0]) else mode[0] # Just take the first one if there are ties
+    if len(mode) > 0:
+        return (
+            0.0 if math.isnan(mode[0]) else mode[0]
+        )  # Just take the first one if there are ties
     else:
         return 0.0
+
+
+def append_fold_column(df: pd.DataFrame, name: str, folds: int) -> pd.DataFrame:
+    """Appends the fold column to the incoming dataframe. Will return a new dataframe, and leave the old one unchanged.
+
+    Parameters
+    ----------
+    df : pd.DataFrame
+        The dataframe.
+    name : str
+        Name of the fold column.
+    folds : int
+        Number of folds we want to cut.
+
+    Returns
+    -------
+    pd.DataFrame
+        The resulting dataframe.
+
+    """
+    res = df.copy()
+    res[name] = np.array((df.index % folds).astype(int))
+    return res
+
+
+def select_and_drop_fold_column(
+    df: pd.DataFrame, name: str, fold: int, test: bool
+) -> pd.DataFrame:
+    """
+    Selects the rows that are in fold range, and then drops the fold column.
+
+    If `test` is `True`, selects the rows with `name` equal to `fold`. Otherwise chooses the ones that are not equal.
+
+    Parameters
+    ----------
+    df : pd.DataFrame
+        The dataframe.
+    name : str
+        Name of fold column.
+    fold : int
+        The fold to select.
+    test : bool
+        Whether we are selecting test frame or not.
+
+    Returns
+    -------
+    pd.DataFrame
+        The selected dataframe.
+
+    """
+    return (
+        df.loc[(df[name] == fold) if test else (df[name] != fold)]
+        .reset_index(drop=True)
+        .drop(columns=[name])
+    )
