@@ -216,8 +216,7 @@ class ClassificationScores(BaseModel):
             )
 
         le = preprocessing.LabelEncoder()
-        le.fit(list(labels))
-        labels = le.transform(labels)
+        labels = le.fit_transform(labels)
         actual = le.transform(actual)
         pred = le.transform(pred)
         log_loss_ = log_loss(actual, pred_proba, labels=labels)
@@ -286,26 +285,26 @@ class CVScores(BaseModel):
     Usage
     -----
     ```python
-    folds: List[Scores] = []
+    split_scores: List[Scores] = []
     for _ in nfolds:
         # dates, actual = extract_from_data(df)
         # pred = model.predict(dates)
-        folds.append(RegressionScores.get_scores(pred, actual))
+        split_scores.append(RegressionScores.get_scores(pred, actual))
     # To get the CV scores that can be sent from FastAPI, do this
-    CVScores(folds=folds).to_report()
+    CVScores(split_scores=split_scores).to_report()
     ```
     """
 
-    folds: List[Scores]
+    split_scores: List[Scores]
 
-    @validator("folds")
+    @validator("split_scores")
     def check_folds(cls, v):
         if not v:
             raise ValueError("No score")
         types = {type(f).__name__ for f in v}
         if len(types) > 1:
             raise ValueError(
-                f"All fold scores must have consistent type. Found {types}"
+                f"All split scores must have consistent type. Found {types}"
             )
         return v
 
@@ -315,6 +314,6 @@ class CVScores(BaseModel):
 
         """
         return {
-            field: [fold.dict()[field] for fold in self.folds]
-            for field in self.folds[0].__fields__
+            field: [score.dict()[field] for score in self.split_scores]
+            for field in self.split_scores[0].__fields__
         }
